4Suite API Documentation: Ft.Lib.DistExt.Install

4Suite™ API Documentation

# ► Module Ft.Lib.DistExt.Install

Classes: Install |  |  |  | Functions: GetBundleScheme |  |  |  | Globals: DEBUG, INSTALL_LOCATIONS, INSTALL_SCHEMES, SCHEME_KEYS, name, scheme

## Classes

class Install(distutils.command.install.install)

  ### Methods

  change_roots(self, *names)
    Overrides: change_roots from class install
  convert_paths(self, *names)
    Overrides: convert_paths from class install
  expand_basedirs(self)
    Overrides: expand_basedirs from class install
  expand_dirs(self)
    Overrides: expand_dirs from class install
  finalize_options(self)
    Overrides: finalize_options from class install
  finalize_other(self)
    Overrides: finalize_other from class install
  finalize_unix(self)
    Overrides: finalize_unix from class install
  get_installation_report(self)
  get_scheme(self, name)
  get_scheme_keys(self)
  get_source_files(self)
  has_config(self)
  has_devel(self)
  has_docs(self)
  has_l10n(self)
  has_localstate(self)
  has_sysconf(self)
  has_text(self)
  initialize_options(self)
    Overrides: initialize_options from class install
  run(self)
    Overrides: run from class install
  select_scheme(self, name)
    Overrides: select_scheme from class install

  ### Methods inherited from class distutils.command.install.install

  create_path_file, dump_dirs, get_inputs, get_outputs, handle_extra_path, has_data, has_headers, has_lib, has_scripts

  ### Methods inherited from class distutils.cmd.Command

  __getattr__, __init__, announce, copy_file, copy_tree, debug_print, dump_options, ensure_dirname, ensure_filename, ensure_finalized, ensure_string, ensure_string_list, execute, get_command_name, get_finalized_command, get_sub_commands, make_archive, make_file, mkpath, move_file, reinitialize_command, run_command, set_undefined_options, spawn, warn

  ### Members

  boolean_options = ['compile', 'force', 'skip-build', 'with-docs', 'local', 'system']
  command_name = 'install'
  index = 14
  negative_opt = {'no-compile': 'compile', 'without-docs': 'with-docs'}
  sub_commands = [('install_lib', <function has_lib>), ('install_headers', <function has_headers>), ('install_scripts', <function has_scripts>), ('install_data', <function has_data>), ('install_sysconf', <function has_sysconf>), ('install_localstate', <function has_localstate>), ('install_devel', <function has_devel>), ('install_text', <function has_text>), ('install_html', <function has_docs>), ('install_l10n', <function has_l10n>), ('install_config', <function has_config>), ('install_egg_info', None)]
  user_options = [('prefix=', None, 'installation prefix'), ('exec-prefix=', None, '(Unix only) prefix for platform-specific files'), ('local', None, '(Unix only) Use FHS /usr/local installation scheme [default]'), ('system', None, '(Unix only) Use FHS /usr system installation scheme'), ('home=', None, '(Unix only) home directory to install under'), ('install-base=', None, 'base installation directory (instead of --prefix or --home)'), ('install-platbase=', None, 'base installation directory for platform-specific files (instead of --exec-prefix or --home)'), ('root=', None, 'install everything relative to this alternate root directory'), ('install-purelib=', None, 'installation directory for pure Python module distributions'), ('install-platlib=', None, 'installation directory for non-pure module distributions'), ('install-lib=', None, 'installation directory for all module distributi...verrides --install-purelib and --install-platlib)'), ('install-headers=', None, 'installation directory for C/C++ headers'), ('install-scripts=', None, 'installation directory for Python scripts'), ('install-data=', None, 'installation directory for data files'), ('install-sysconf=', None, 'installation directory for read-only host-specific data'), ('install-localstate=', None, 'installation directory for modifiable host-specific data'), ('install-devel=', None, 'installation directory for development files (regression tests)'), ('install-l10n=', None, 'installation directory for message catalogs'), ('install-docs=', None, 'installation directory for documentation files'), ('compile', 'c', 'compile .py to .pyc [default]'), ...]

  ### Members inherited from class distutils.command.install.install

  description

## Functions

GetBundleScheme()

## Globals

DEBUG = None
INSTALL_LOCATIONS = {'install_data': 'Examples, demos and other miscellaneous data files', 'install_devel': 'Developer files (regression tests)', 'install_headers': 'C/C++ header files', 'install_html': 'HTML documentation', 'install_l10n': 'Natural language message catalogs', 'install_lib': 'Python modules (including C extensions)', 'install_localstate': 'Machine-specific variable data space', 'install_scripts': 'Executable scripts (for PATH environment variable)', 'install_sysconf': 'Configuration files', 'install_text': 'Text documentation'}
INSTALL_SCHEMES = {'default': {'base': '$exec', 'data': '$datadir', 'devel': '$libdir', 'docs': '$docdir', 'headers': '$includedir', 'l10n': '$localedir', 'localstate': '$localstatedir', 'man': '$mandir', 'platbase': '$exec_prefix', 'platlib': '$pythonlibdir', ...}, 'mac': {'data': '$base/Share/$dist_name', 'devel': '$base/Share/$dist_name', 'docs': '$base/Share/Doc/$dist_name', 'headers': '$base/Include/$dist_name', 'l10n': '$base/Share/Locale', 'localstate': '$base/Share/$dist_name', 'man': '$base/Share/Help', 'platlib': '$base/Lib/site-packages', 'purelib': '$base/Lib/site-packages', 'scripts': '$base/Scripts', ...}, 'nt': {'data': '$base/Share/$dist_name', 'devel': '$base/Share/$dist_name', 'docs': '$base/Share/Doc/$dist_name', 'headers': '$base/Include/$dist_name', 'l10n': '$base/Share/Locale', 'localstate': '$base/Share/$dist_name', 'man': '$base/Share/Help', 'platlib': '$base/Lib/site-packages', 'purelib': '$base/Lib/site-packages', 'scripts': '$base/Scripts', ...}, 'os2': {'data': '$base/Share/$dist_name', 'devel': '$base/Share/$dist_name', 'docs': '$base/Share/Doc/$dist_name', 'headers': '$base/Include/$dist_name', 'l10n': '$base/Share/Locale', 'localstate': '$base/Share/$dist_name', 'man': '$base/Share/Help', 'platlib': '$base/Lib/site-packages', 'purelib': '$base/Lib/site-packages', 'scripts': '$base/Scripts', ...}, 'unix_home': {'data': '$base/share/$dist_name', 'devel': '$base/lib/$dist_name', 'docs': '$base/share/doc/$dist_name', 'headers': '$base/include/python/$dist_name', 'l10n': '$base/share/locale', 'localstate': '$base/share/var/$dist_name', 'man': '$base/share/man', 'platlib': '$base/lib/python$py_version_short', 'purelib': '$base/lib/python$py_version_short', 'scripts': '$base/bin', ...}, 'unix_local': {'data': '/usr/local/share/$dist_name', 'devel': '/usr/local/lib/$dist_name', 'docs': '/usr/local/share/doc/$dist_name', 'headers': '/usr/local/include/$dist_name', 'l10n': '/usr/local/share/locale', 'localstate': '/var/local/lib/$dist_name', 'man': '/usr/local/share/man', 'platlib': '/usr/local/lib/python$py_version_short/site-packages', 'purelib': '/usr/local/lib/python$py_version_short/site-packages', 'scripts': '/usr/local/bin', ...}, 'unix_prefix': {'data': '$base/share/$dist_name', 'devel': '$platbase/lib/$dist_name', 'docs': '$base/share/doc/$dist_name', 'headers': '$base/include/python$py_version_short/$dist_name', 'l10n': '$base/share/locale', 'localstate': '$platbase/var/$dist_name', 'man': '$base/man', 'platlib': '$platbase/lib/python$py_version_short/site-packages', 'purelib': '$base/lib/python$py_version_short/site-packages', 'scripts': '$base/bin', ...}, 'unix_system': {'data': '/usr/share/$dist_name', 'devel': '/usr/lib/$dist_name', 'docs': '/usr/share/doc/$dist_name', 'headers': '/usr/include/$dist_name', 'l10n': '/usr/share/locale', 'localstate': '/var/lib/$dist_name', 'man': '/usr/share/man', 'platlib': '/usr/lib/python$py_version_short/site-packages', 'purelib': '/usr/lib/python$py_version_short/site-packages', 'scripts': '/usr/bin', ...}, 'zip': {'base': '', 'data': '$base/Share', 'devel': None, 'docs': None, 'headers': None, 'l10n': '$base/Share/Locale', 'localstate': None, 'man': None, 'platbase': '', 'platlib': '$base', ...}}
SCHEME_KEYS = ('purelib', 'platlib', 'headers', 'scripts', 'data', 'sysconf', 'localstate', 'devel', 'l10n', 'man', 'docs')
name = 'unix_home'
scheme = {'data': '$base/share/$dist_name', 'devel': '$base/lib/$dist_name', 'docs': '$base/share/doc/$dist_name', 'headers': '$base/include/python/$dist_name', 'l10n': '$base/share/locale', 'localstate': '$base/share/var/$dist_name', 'man': '$base/share/man', 'platlib': '$base/lib/python$py_version_short', 'purelib': '$base/lib/python$py_version_short', 'scripts': '$base/bin', ...}